=== modified file 'AllDayEventComponent.qml'
--- AllDayEventComponent.qml	2014-09-20 10:45:35 +0000
+++ AllDayEventComponent.qml	2014-09-21 09:39:21 +0000
@@ -115,7 +115,7 @@
                             text =  i18n.tr("%1 Ev.").arg(events.length)
                         } else {
                             if( events.length > 1) {
-                                text = i18n.tr("%1 All day events").arg(events.length)
+                                text = i18n.tr("%1 All day event", "%1 All day events", events.length).arg(events.length)
                             } else {
                                 text = events[0].displayLabel;
                             }

=== modified file 'DayView.qml'
--- DayView.qml	2014-09-19 12:28:53 +0000
+++ DayView.qml	2014-09-21 09:39:21 +0000
@@ -54,13 +54,17 @@
 
             Label {
                 fontSize: "medium"
-                text: i18n.tr(currentDay.toLocaleString(Qt.locale(),i18n.tr("dddd")))
+                text: Qt.locale().standaloneDayName(currentDay.getDay())
+                font.capitalization: Font.Capitalize
             }
 
             Label {
                 id:cuurentDay
                 objectName:"monthYearLabel"
                 fontSize: "large"
+                // TRANSLATORS: this is a time formatting string,
+                // see http://qt-project.org/doc/qt-5/qml-qtqml-date.html#details for valid expressions.
+                // It's used in the header of the day view
                 text:i18n.tr(currentDay.toLocaleString(Qt.locale(),i18n.tr("MMMM dd, yyyy")))
             }
         }

=== modified file 'EventDetails.qml'
--- EventDetails.qml	2014-09-17 21:33:23 +0000
+++ EventDetails.qml	2014-09-21 09:39:21 +0000
@@ -119,10 +119,13 @@
     function showEvent(e) {
         // TRANSLATORS: this is a time formatting string,
         // see http://qt-project.org/doc/qt-5/qml-qtqml-date.html#details for valid expressions
-        var timeFormat = i18n.tr("hh:mm");
-        // TRANSLATORS: this is a time & Date formatting string,
-        //see http://qt-project.org/doc/qt-5/qml-qtqml-date.html#details
-        var dateFormat = i18n.tr("dd-MMM-yyyy")
+        // It's used to display the start and end times of an event in the event details
+        // and new event views
+        var timeFormat = Qt.locale().timeFormat(Locale.ShortFormat);
+        // TRANSLATORS: this is a date formatting string,
+        // see http://qt-project.org/doc/qt-5/qml-qtqml-date.html#details for valid expressions
+        // It's used to display the date in the event details view
+        var dateFormat = i18n.tr("MMMM dd, yyyy")
         eventDate.value = e.startDateTime.toLocaleString(Qt.locale(),dateFormat);
         var startTime = e.startDateTime.toLocaleTimeString(Qt.locale(), timeFormat);
         var endTime = e.endDateTime.toLocaleTimeString(Qt.locale(), timeFormat);
@@ -281,7 +284,7 @@
                 visible: allDayEventCheckbox.checked
 
                 Label {
-                    text: i18n.tr("All Day event:")
+                    text: i18n.tr("All day event")
                     anchors.verticalCenter: allDayEventCheckbox.verticalCenter
                     color: headerColor
                 }
@@ -394,12 +397,12 @@
             EventDetailsInfo{
                 id: recurrentHeader
                 xMargin: column.recurranceAreaMaxWidth
-                header: i18n.tr("This happens")
+                header: i18n.tr("Repeats")
             }
             EventDetailsInfo{
                 id: reminderHeader
                 xMargin: column.recurranceAreaMaxWidth
-                header: i18n.tr("Remind me")
+                header: i18n.tr("Reminder")
             }
 
         }

=== modified file 'EventUtils.qml'
--- EventUtils.qml	2014-09-16 11:35:18 +0000
+++ EventUtils.qml	2014-09-21 09:39:21 +0000
@@ -78,7 +78,7 @@
         var index;
         var reccurence = "";
         var limit,str = "";
-        var dateFormat = i18n.tr("ddd MMMM d yyyy");
+        var dateFormat = Qt.locale().dateFormat(Locale.LongFormat);
         index = rule.frequency;
         if(index === RecurrenceRule.Weekly){
             index = getWeekDaysIndex(rule.daysOfWeek.sort() )

=== modified file 'MonthView.qml'
--- MonthView.qml	2014-09-19 15:10:04 +0000
+++ MonthView.qml	2014-09-21 09:39:21 +0000
@@ -50,7 +50,11 @@
 
         contents: Label {
             fontSize: "x-large"
+            // TRANSLATORS: this is a time formatting string,
+            // see http://qt-project.org/doc/qt-5/qml-qtqml-date.html#details for valid expressions.
+            // It's used in the header of the month and week views
             text: i18n.tr(currentMonth.toLocaleString(Qt.locale(),i18n.tr("MMMM yyyy")))
+            font.capitalization: Font.Capitalize
         }
     }
 

=== modified file 'NewEvent.qml'
--- NewEvent.qml	2014-09-20 10:45:35 +0000
+++ NewEvent.qml	2014-09-21 09:39:21 +0000
@@ -78,7 +78,7 @@
         if (typeof(endDate) === 'undefined') {
             endDate = new Date(root.roundDate(date))
             endDate.setMinutes(endDate.getMinutes() + 30)
-            endTimeInput.text = Qt.formatDateTime(endDate, "hh:mm");
+            endTimeInput.text = Qt.formatDateTime(endDate, Qt.locale().timeFormat(Locale.ShortFormat));
         }
 
         if(event === null){
@@ -426,7 +426,7 @@
                     leftMargin: units.gu(-1)
                 }
 
-                text: "All Day Event"
+                text: i18n.tr("All day event")
                 showDivider: false
                 control: CheckBox {
                     id: allDayEventCheckbox
@@ -601,7 +601,7 @@
                 showDivider: false
                 progression: true
                 visible: event.itemType === Type.Event
-                text: i18n.tr("This Happens")
+                text: i18n.tr("Repeats")
                 subText: eventUtils.getRecurrenceString(rule)
                 onClicked: pageStack.push(Qt.resolvedUrl("EventRepetition.qml"),{"rule": rule,"date":date,"isEdit":isEdit});
             }

=== modified file 'WeekView.qml'
--- WeekView.qml	2014-09-19 09:40:55 +0000
+++ WeekView.qml	2014-09-21 09:39:21 +0000
@@ -58,6 +58,7 @@
             objectName:"monthYearLabel"
             fontSize: "x-large"
             text: i18n.tr(dayStart.toLocaleString(Qt.locale(),i18n.tr("MMMM yyyy")))
+            font.capitalization: Font.Capitalize
         }
     }
 

